==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/parser/sql/statement/core/src/main/java/org/apache/shardingsphere/sql/parser/statement/core/segment/ddl/cursor/DirectionSegment.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sql.parser.statement.core.segment.ddl.cursor;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import org.apache.shardingsphere.sql.parser.statement.core.enums.DirectionType;
import org.apache.shardingsphere.sql.parser.statement.core.segment.SQLSegment;

import java.util.Optional;

/**
 * Direction segment.
 */
@RequiredArgsConstructor
@Getter
@Setter
public final class DirectionSegment implements SQLSegment {
    
    private final int startIndex;
    
    private final int stopIndex;
    
    private DirectionType directionType;
    
    private Long count;
    
    /**
     * Get direction type.
     *
     * @return direction type
     */
    public Optional<DirectionType> getDirectionType() {
        return Optional.ofNullable(directionType);
    }
    
    /**
     * Get count.
     *
     * @return count
     */
    public Optional<Long> getCount() {
        return Optional.ofNullable(count);
    }
}

==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/parser/sql/statement/core/src/main/java/org/apache/shardingsphere/sql/parser/statement/core/segment/ddl/cursor/DirectionSegment.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sql.parser.statement.core.segment.ddl.cursor;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.sql.parser.statement.core.enums.DirectionType;
import org.apache.shardingsphere.sql.parser.statement.core.segment.SQLSegment;

import java.util.Optional;

/**
 * Direction segment.
 */
@RequiredArgsConstructor
@Getter
public final class DirectionSegment implements SQLSegment {
    
    private final int startIndex;
    
    private final int stopIndex;
    
    private final DirectionType directionType;
    
    private final Long count;
    
    public DirectionSegment(final int startIndex, final int stopIndex, final DirectionType directionType) {
        this(startIndex, stopIndex, directionType, null);
    }
    
    /**
     * Get count.
     *
     * @return count
     */
    public Optional<Long> getCount() {
        return Optional.ofNullable(count);
    }
}
